from setuptools import setup, find_packages

setup(
    name='pixegrami_hello',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        #Add dependecies here.
        #e.g. 'numpy>=1.11.1'
    ],
)